:py:mod:`piel.sax`
==================

.. py:module:: piel.sax


Submodules
----------
.. toctree::
   :titlesonly:
   :maxdepth: 1

   utils/index.rst


Package Contents
----------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.sax.get_common_netlist_instance_keys



.. py:function:: get_common_netlist_instance_keys() -> list

   Get the common netlist instance keys for a given netlist.

   :returns: List of common netlist instance keys.
   :rtype: list
